@@ -118,13 +118,17 @@ AreaPlotAtomic <- function(
 #' data <- data.frame(
 #'     x = rep(c("A", "B", "C", "D"), 2),
 #'     y = c(1, 3, 6, 4, 2, 5, 7, 8),
-#'     group = rep(c("F1", "F2"), each = 4)
+#'     group = rep(c("F1", "F2"), each = 4),
+#'     split = rep(c("X", "Y"), 4)
 #' )
 #' AreaPlot(data, x = "x", y = "y", group_by = "group")
 #' AreaPlot(data, x = "x", y = "y", group_by = "group",
 #'          scale_y = TRUE)
 #' AreaPlot(data, x = "x", y = "y", split_by = "group")
 #' AreaPlot(data, x = "x", y = "y", split_by = "group", palette = c(F1 = "Blues", F2 = "Reds"))
+#' AreaPlot(data, x = "x", y = "y", group_by = "group", split_by = "split",
+#'     legend.direction = c(X = "horizontal", Y = "vertical"),
+#'     legend.position = c(X = "top", Y = "right"))
 AreaPlot <- function(
     data, x, y = NULL, x_sep = "_", split_by = NULL, split_by_sep = "_",
     group_by = NULL, group_by_sep = "_", group_name = NULL, scale_y = FALSE,
@@ -132,7 +136,8 @@ AreaPlot <- function(
     facet_by = NULL, facet_scales = "fixed", facet_ncol = NULL, facet_nrow = NULL, facet_byrow = TRUE,
     x_text_angle = 0, aspect.ratio = 1, legend.position = waiver(), legend.direction = "vertical",
     title = NULL, subtitle = NULL, xlab = NULL, ylab = NULL, keep_empty = FALSE, seed = 8525,
-    combine = TRUE, nrow = NULL, ncol = NULL, byrow = TRUE, ...
+    combine = TRUE, nrow = NULL, ncol = NULL, byrow = TRUE, axes = NULL, axis_titles = axes, guides = NULL,
+    design = NULL, ...
 ){
     validate_common_args(seed, facet_by = facet_by)
     theme <- process_theme(theme)
@@ -148,6 +153,8 @@ AreaPlot <- function(
     }
     palette <- check_palette(palette, names(datas))
     palcolor <- check_palcolor(palcolor, names(datas))
+    legend.direction <- check_legend(legend.direction, names(datas), "legend.direction")
+    legend.position <- check_legend(legend.position, names(datas), "legend.position")
 
     plots <- lapply(
         names(datas), function(nm) {
@@ -162,11 +169,12 @@ AreaPlot <- function(
                 x = x, y = y, x_sep = x_sep, group_by = group_by, group_by_sep = group_by_sep, group_name = group_name, scale_y = scale_y,
                 theme = theme, theme_args = theme_args, palette = palette[[nm]], palcolor = palcolor[[nm]], alpha = alpha,
                 facet_by = facet_by, facet_scales = facet_scales, facet_ncol = facet_ncol, facet_nrow = facet_nrow, facet_byrow = facet_byrow,
-                x_text_angle = x_text_angle, aspect.ratio = aspect.ratio, legend.position = legend.position, legend.direction = legend.direction,
+                x_text_angle = x_text_angle, aspect.ratio = aspect.ratio, legend.position = legend.position[[nm]], legend.direction = legend.direction[[nm]],
                 title = title, subtitle = subtitle, xlab = xlab, ylab = ylab, keep_empty = keep_empty, ...
             )
         }
     )
 
-    combine_plots(plots, combine = combine, nrow = nrow, ncol = ncol, byrow = byrow)
+    combine_plots(plots, combine = combine, nrow = nrow, ncol = ncol, byrow = byrow,
+        axes = axes, axis_titles = axis_titles, guides = guides, design = design)
 }
