@@ -256,7 +256,7 @@ facet_plot <- function(plot, facet_by, facet_scales, nrow, ncol, byrow,
 #' @importFrom rlang %||%
 #' @importFrom ggplot2 wrap_dims
 combine_plots <- function(
-    plots, combine,
+    plots, combine = TRUE,
     nrow = NULL,
     ncol = NULL,
     byrow = NULL,
@@ -284,8 +284,11 @@ combine_plots <- function(
             design = design,
             recalc_size = FALSE
         )
-        attr(p, "height") <- nrow * max(sapply(plots, function(x) attr(x, "height")))
-        attr(p, "width") <- ncol * max(sapply(plots, function(x) attr(x, "width")))
+        # Allow to work with external plots
+        tryCatch({
+            attr(p, "height") <- nrow * max(sapply(plots, function(x) attr(x, "height")))
+            attr(p, "width") <- ncol * max(sapply(plots, function(x) attr(x, "width")))
+        }, error = function(e) {})
         return(p)
     }
     # When it's gTree, also run wrap_plots to convert it to a patchwork object
@@ -578,6 +581,10 @@ check_palcolor <- function(palcolor, datas_name) {
     # as.list() will turn c("red", "blue") into list("red", "blue")
     # but we need list(c("red", "blue"))
     if (!is.list(palcolor)) { palcolor <- list(palcolor) }
+    if (identical(datas_name, "...") && !identical(names(palcolor), "...")) {
+        palcolor <- list(palcolor)
+        names(palcolor) <- datas_name
+    }
     if (length(palcolor) == 1 && length(datas_name) > 1) {
         palcolor <- rep(palcolor, length(datas_name))
     }
